import { useState, useEffect, useCallback } from 'react'
import aiService, { AIMessage, AIData, AI_OPTIONS } from '@/utils/ai'

export function useAI() {
  const [ai, setAI] = useState<string>(localStorage.getItem('ai') || 'qwen')
  const [messages, setMessages] = useState<AIMessage[]>([])
  const [isLoading, setIsLoading] = useState<boolean>(false)
  useEffect(() => {
    localStorage.setItem('ai', ai)
  }, [ai])

  const post = useCallback(
    async (data: AIData) => {
      setIsLoading(true)
      setMessages((prevMessages) => [...prevMessages, ...data.messages.filter((item) => item.role !== 'system')])
      try {
        await aiService.post(ai, data, {
          onUpdate: (response) => {
            setMessages((prevMessages) => {
              const messageIndex = prevMessages.findIndex((msg) => msg.id === response.id)
              if (messageIndex === -1) {
                return [...prevMessages, { id: response.id, role: 'assistant', content: response.content }]
              } else {
                return prevMessages.map((msg) =>
                  msg.id === response.id ? { ...msg, content: msg.content + response.content } : msg
                )
              }
            })
          },
          onError: (err) => {
            console.error('AI 请求失败:', err)
            setIsLoading(false)
          },
          onComplete: () => {
            setIsLoading(false)
          },
        })
      } catch (err) {
        console.error('AI 请求失败:', err)
        setIsLoading(false)
      }
    },
    [ai]
  )

  return { ai, setAI, options: AI_OPTIONS, post, messages, isLoading }
}
