import { Card, Button, Row, Col, Carousel } from 'antd'
import { Link } from 'react-router'
import { Database, SearchCheck, Filter, Bolt, Cone, ChartArea, Wallpaper } from 'lucide-react'
import '../styles.scss'

type CardItem = {
  icon: React.ReactNode
  title: string
  description: string
  path: string
}

export default function DataDashboard() {
  const items: CardItem[] = [
    {
      icon: <Database size={40} />,
      title: '数据采集',
      description: '多源数据采集与结构化导入',
      path: '/data/write',
    },
    {
      icon: <SearchCheck size={40} />,
      title: '数据理解与探索',
      description: '动态化数据理解与深度模式探索',
      path: '/data/read',
    },
    {
      icon: <Filter size={40} />,
      title: '数据预处理',
      description: '智能化数据预处理范式',
      path: '/data/preprocess',
    },
    {
      icon: <Bolt size={40} />,
      title: '数据加工',
      description: '‌多模态数据加工架构',
      path: '/data/process',
    },
    {
      icon: <Cone size={40} />,
      title: '数据挖掘',
      description: '智能数据解析与知识图谱构建‌‌',
      path: '/data/digging',
    },
    {
      icon: <ChartArea size={40} />,
      title: '可视化组件',
      description: '‌智能可视化组件',
      path: '/data/chart',
    },
    {
      icon: <Wallpaper size={40} />,
      title: '可视化大屏',
      description: '‌智能可视化大屏',
      path: '/data/screen',
    },
  ]

  const CardCardItem = (item: CardItem) => {
    return (
      <Card>
        <div className="card-item">
          <div className="card-item__left">
            <h3>{item.title}</h3>
            <p>{item.description}</p>
            <br />
            <Link to={item.path}>
              <Button shape="round">点击进入</Button>
            </Link>
          </div>
          <div className="card-item__right">{item.icon}</div>
        </div>
      </Card>
    )
  }

  return (
    <div style={{ margin: '0 80px' }}>
      <Card style={{ marginBottom: 40 }}>
        <Carousel className="carousel-banner">
          <div className="banner">
            <h2>AI驱动的数据分析实验室</h2>
            <p>
              以AI技术为核心驱动力，深度挖掘数据价值，为各领域提供精准、高效的数据分析解决方案，助力决策智能化与业务创新。
            </p>
          </div>
          <div className="banner">
            <h2>AI驱动的数据分析实验室</h2>
            <p>
              以AI技术为核心驱动力，深度挖掘数据价值，为各领域提供精准、高效的数据分析解决方案，助力决策智能化与业务创新。
            </p>
          </div>
        </Carousel>
      </Card>
      <Row gutter={[40, 40]}>
        {items.map((item) => (
          <Col span={6} key={item.path}>
            {CardCardItem(item)}
          </Col>
        ))}
      </Row>
    </div>
  )
}
