import { create } from 'zustand'
import aiService, { AIOption, AIMessage, AIData, AI_OPTIONS } from '@/utils/ai'

interface AIState {
  ai: string
  options: AIOption[]
  messages: AIMessage[]
  isLoading: boolean
  collapsed: boolean
  setAI: (ai: string) => void
  toggleCollapsed: () => void
  post: (data: AIData) => Promise<void>
}

export const useAIStore = create<AIState>((set, get) => ({
  ai: localStorage.getItem('ai') || 'qwen',
  options: AI_OPTIONS,
  messages: [],
  isLoading: false,
  collapsed: false,
  setAI: (ai) => {
    localStorage.setItem('ai', ai)
    set({ ai })
  },
  toggleCollapsed: () => {
    set((state) => ({ collapsed: !state.collapsed }))
  },
  post: async (data) => {
    const { ai, messages } = get()

    set({
      collapsed: true,
      isLoading: true,
      messages: [...messages, ...data.messages.filter((item) => item.role !== 'system')],
    })

    try {
      await aiService.post(ai, data, {
        onUpdate: (response) => {
          set((state) => {
            const messageIndex = state.messages.findIndex((msg) => msg.id === response.id)
            if (messageIndex === -1) {
              return {
                messages: [...state.messages, { id: response.id, role: 'assistant', content: response.content }],
              }
            } else {
              return {
                messages: state.messages.map((msg) =>
                  msg.id === response.id ? { ...msg, content: msg.content + response.content } : msg
                ),
              }
            }
          })
        },
        onError: (err) => {
          console.error('AI 请求失败:', err)
          set({ isLoading: false })
        },
        onComplete: () => {
          set({ isLoading: false })
        },
      })
    } catch (err) {
      console.error('AI 请求失败:', err)
      set({ isLoading: false })
    }
  },
}))

export type { AIMessage }
